@@ -55,8 +55,8 @@ macro_rules! table {
         pub struct $name { $(pub $field: $kind,)* }
     );
     (@implement pub $name:ident { $($field:ident,)* }) => (
-        impl $crate::Value for $name {
-            fn read<T: $crate::Tape>(tape: &mut T) -> $crate::Result<Self> {
+        impl ::Value for $name {
+            fn read<T: ::Tape>(tape: &mut T) -> ::Result<Self> {
                 let mut table: $name = unsafe { ::std::mem::zeroed() };
                 $(::std::mem::forget(::std::mem::replace(&mut table.$field, try!(tape.take())));)+
                 Ok(table)
